summaryrefslogtreecommitdiffstats
path: root/ui/gfx/font.h
diff options
context:
space:
mode:
authormsw@chromium.org <msw@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2013-02-01 04:42:17 +0000
committermsw@chromium.org <msw@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2013-02-01 04:42:17 +0000
commitccfa43f042db868f6584f9cceef94ca7c4ddf239 (patch)
treef3f3980981147928cae30754448f88d45527d2d0 /ui/gfx/font.h
parent8c49a50da6675ed9329b01a1e960c78e42d4ba82 (diff)
downloadchromium_src-ccfa43f042db868f6584f9cceef94ca7c4ddf239.zip
chromium_src-ccfa43f042db868f6584f9cceef94ca7c4ddf239.tar.gz
chromium_src-ccfa43f042db868f6584f9cceef94ca7c4ddf239.tar.bz2
Replace StyleRange with BreakList; update RenderText, etc.
This is a functional rewrite with no observable behavior/appearance changes. (it helps by merging adjacent equivalent styles, reducing artificial run breaks) (it helps disambiguate font/adornment styles for application in layout/drawing) Remove gfx::StyleRange and its use within gfx::RenderText[Win|Linux|Mac]. Add new BreakList class for managing [ranged] colors and styles; add/update tests. Add gfx::TextStyle enum for bold, italic, underline, strike, and diagonal strike. Split ApplyStyleRange into [Set|Apply]Color and [Set|Apply]Style. Split ApplyDefaultStyle and |default_style_| into the first colors_ and styles_. Split up SkiaTextRenderer::DrawDecorations for Underline/Strike/DiagonalStrike. Update ApplyCompositionAndSelectionStyles, add UndoCompositionAndSelectionStyles. Add temporary StyleIterator convenience class for RenderText subclass style iteration. Update RenderText[Win|Linux|Mac], Textfield classes, and other users. Simplify OmniboxResultView (nix bold font, and ClassificationData). Rename gfx::Font::FontStyle::UNDERLINE (was UNDERLINED); TODO(followup): Only break runs for bold/italic, color/adorn while drawing. TODO(followup): Support more custom/ranged colors; merge TextStyle/FontStyle? BUG=90426,164047,131660 TEST=No observable appearance/performance/behavior changes. R=asvitkine@chromium.org,pkasting@chromium.org,sky@chromium.org Review URL: https://chromiumcodereview.appspot.com/11535014 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@180067 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'ui/gfx/font.h')
-rw-r--r--ui/gfx/font.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/ui/gfx/font.h b/ui/gfx/font.h
index aa2b1c7..c05e76c 100644
--- a/ui/gfx/font.h
+++ b/ui/gfx/font.h
@@ -25,7 +25,7 @@ class UI_EXPORT Font {
NORMAL = 0,
BOLD = 1,
ITALIC = 2,
- UNDERLINED = 4,
+ UNDERLINE = 4,
};
// Creates a font with the default name and style.
@@ -56,7 +56,7 @@ class UI_EXPORT Font {
// |size_delta| is the size in pixels to add to the current font. See the
// single argument version of this method for an example.
// The style parameter specifies the new style for the font, and is a
// bitmask of the values: BOLD, ITALIC and UNDERLINED.
Font DeriveFont(int size_delta, int style) const;
// Returns the number of vertical pixels needed to display characters from
@@ -56,7 +56,7 @@ class UI_EXPORT Font {
// single argument version of this method for an example.
// The style parameter specifies the new style for the font, and is a
- // bitmask of the values: BOLD, ITALIC and UNDERLINED.
+ // bitmask of the values: BOLD, ITALIC and UNDERLINE.
Font DeriveFont(int size_delta, int style) const;
// Returns the number of vertical pixels needed to display characters from